
# Type: pairwise gene to gene interaction_relation




URI: [biolink:pairwise_gene_to_gene_interaction_relation](https://w3id.org/biolink/vocab/pairwise_gene_to_gene_interaction_relation)


## Domain and Range

[PairwiseGeneToGeneInteraction](PairwiseGeneToGeneInteraction.md) ->  <sub>REQ</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents

 *  is_a: [relation](relation.md)

## Children


## Used by

 * [PairwiseGeneToGeneInteraction](PairwiseGeneToGeneInteraction.md)
